==> FluentWidgets-1.0.5-py3-none-any.whl: FluentWidgets/customwidgets/custom_fluent_icon.py <==
from enum import Enum

from qfluentwidgets import Theme, FluentIconBase, getIconColor


class WinPngFluentIcon(FluentIconBase, Enum):
    """ Custom Windows Style Icon (PNG) """

    ADD_CHAT = "AddChat"
    ADD_EMAIL = "AddEmail"
    ADD_FOLDER = "AddFolder"
    ADD_LINK = "AddLink"
    ADD_EMAIL_MESSAGE = "AddEmailMessage"
    ADDRESS = "Address"
    ATTACH = "Attach"
    CALC = "Calc"
    CALENDAR = "Calendar"
    CART = "Cart"
    CHAT = "Chat"
    CHAT_BUBBLES = "ChatBubbles"
    CHAT_MESSAGE = "ChatMessage"
    CLOUD = "Cloud"
    CLOUD_FOLDER = "CloudFolder"
    CODE_FOLDER = "CodeFolder"
    COLOR_WIFI = "ColorWifi"
    COMMENT = "Comment"
    CONTACT = "Contact"
    COPY_TO_FOLDER = "CopyToFolder"
    DATA_BASE = "DataBase"
    DEL_FOLDER = "DelFolder"
    DOCUMENT_FOLDER = "DocumentFolder"
    DOUBT = "Doubt"
    DOWN = "Down"
    DOWNLOAD_FOLDER = "DownloadFolder"
    DROP_DOWN = "DropDown"
    DROP_LEFT = "DropLeft"
    DROP_RIGHT = "DropRight"
    DROP_UP = "DropUp"
    EDIT_CALENDAR = "EditCalendar"
    EDIT_FILE = "EditFile"
    EMAIL_MESSAGE = "EmailMessage"
    ERROR_LINK = "ErrorLink"
    ERROR_WIFI = "ErrorWIFI"
    EXPLORER = "Explorer"
    FEMAIL_USER = "FemailUser"
    FINISH = "Finish"
    FOLDER = "Folder"
    FORWARD = "Forward"
    GAME_FOLDER = "GameFolder"
    GO_AHEAD = "GoAhead"
    HELP = "Help"
    INFO = "Info"
    LEFT = "Left"
    LIKE = "Like"
    LOW_POWER = "LowPower"
    MAN_USER = "ManUser"
    MESSAGE = "Message"
    MICROSOFT = "Microsoft"
    MORE = "More"
    MOVE_TO_FOLDER = "MoveToFolder"
    MSF_STORE = "MSFStore"
    MUSIC_FOLDER = "MusicFolder"
    NO_NETWORK = "NoNetwork"
    NOTEPAD = "Notepad"
    PAINT = "Paint"
    PICTURE_FOLDER = "PictureFolder"
    PLAY = "Play"
    QUICK_SHARK = "QuickShark"
    RADIUS_WIN11_LOG = "RadiusWin11Log"
    REGEDIT = "Regedit"
    RETURN = "Return"
    RIGHT = "Right"
    SEND = "Send"
    RIGHT_SIGN_IN = "RightSignIn"
    ROTATION_LEFT = "RotationLeft"
    ROTATION_RIGHT = "RotationRight"
    ROUND = "Round"
    SAN_WARNING = "SanWarning"
    SAVE = "Save"
    SEARCH_CHAT = "SearchChat"
    SEARCH_MORE = "SearchMore"
    SETTING = "Setting"
    SHARK = "Shark"
    SHI_ZHON = "ShiZhon"
    SIGN = "Sign"
    SORT_DOWN = "SortDown"
    SORT_LEFT = "SortLeft"
    SORT_RIGHT = "SortRight"
    SORT_UP = "SortUp"
    SUN_CLOUD = "SunCloud"
    TERMINAL = "Terminal"
    TOOL = "Tool"
    TOP_SEND = "TopSend"
    VIDEO = "Video"
    VIDEO_FOLDER = "VideoFolder"
    WARNING = "Warning"
    WEATHER = "Weather"
    WHITE_WIFI = "WhiteWIFI"
    ZIP_FOLDER = "ZipFolder"
    WIN_11_LOG = "Win11Log"
    XIAN_JI = "XianJi"
    XIN_HAO = "XinHao"
    ZERO = "Zero"
    ONE = "One"
    TWO = "Two"
    THREE = "Three"
    FOUR = "Four"
    FIVE = "Five"
    SIX = "Six"
    SEVEN = "Seven"
    EIGHT = "Eight"
    NINE = "Nine"
    TEN = "Ten"
    ROUND_ZERO = "RoundZero"
    ROUND_ONE = "RoundOne"
    ROUND_TWO = "RoundTwo"
    ROUND_THREE = "RoundThree"
    ROUND_FOUR = "RoundFour"
    ROUND_FIVE = "RoundFive"
    ROUND_SIX = "RoundSix"
    ROUND_SEVEN = "RoundSeven"
    ROUND_EIGHT = "RoundEight"
    ROUND_NINE = "RoundNine"

    def path(self, theme=Theme.AUTO):
        # return f"C:\Projects\Items\Python\QFluentWidgets\data\images\logo\{self.value}.png"
        return fr"..\..\data\images\icons\WindowStyleIcons\PNG\{self.value}.png"


class WinSvgFluentIcon(FluentIconBase, Enum):
    """ Custom Window Style Icon (SVG) """

    CLoud = "Cloud"
    FINISH = "Finish"
    HOME = "Home"
    INFO = "Info"
    MENU = "Menu"
    MUSIC = "Music"
    PICTURE = "Picture"
    POWER_SHELL = "PowerShell"
    RECYCLE_BIN = "RecycleBin"
    WIN_10_COLOR_LOG = "Win10ColorLog"
    WIN_11_COLOR_LOG = "Win11ColorLog"


    def path(self, theme=Theme.AUTO):
        # return f"C:\Projects\Items\Python\QFluentWidgets\data\images\logo\{self.value}.png"
        return fr"..\..\data\images\icons\WindowStyleIcons\SVG\{self.value}.svg"


class CustomFluentIcon(FluentIconBase, Enum):
    """ Custom Fluent Icon"""

    ADD_CHAT = "AddChat"
    ADD_FILE = "AddFile"
    ATTACH = "Attach"
    CHAT = "Chat"
    CHAT_BUBBLES = "ChatBubbles"
    CHAT_MESSAGE = "ChatMessage"
    EDIT_FILE = "EditFile"
    EMAIL_MESSAGE = "EmailMessage"
    FINISH = "Finish"
    NONE_BILI = "NoneBili"
    OPEN_FILE = "OpenFile"
    OPEN_FOLDER = "OpenFolder"
    SEND = "Send"
    SEND_FILL = "SendFill"

    def path(self, theme=Theme.AUTO):
        return fr"..\..\data\images\icons\NormalIcon\{self.value}\{getIconColor()}.png"


class ColorFluentIcon(FluentIconBase, Enum):
    """ Color Fluent Icon """

    ADD = "Add"
    ADOBE = "Adobe"
    PDF = "PDF"
    AE = "AE"
    AI = "AI"
    AN = "AN"
    AU = "AU"
    DW = "DW"
    ID = "ID"
    PR = "PR"
    PS = "PS"
    XD = "XD"
    FLY_MODE = "FlyModule"
    CHROME = "GoogleChrome"
    MAC = "MAC"
    APPLE_STORE = "AppStore"

    def path(self, theme=Theme.AUTO):
        return fr"..\..\data\images\icons\ColorStyleIcons\{self.value}.png"


class AppFluentIcon(FluentIconBase, Enum):

    AMD = "AMD"
    CALL_OF_DUTY = "CallOfDuty"
    CSGO = "CSGO"
    EDGE = "Edge"
    WORD = "Word"
    EXCEL = "Excel"
    PPT = "PPT"
    GMAIL = "Gmail"
    CHROME = "GoogleChrome"
    GOOGLE_CLOUD_DISK = "GoogleCloudDisk"
    GOOGLE_DOCUMENT = "GoogleDocument"
    GOOGLE_PLAY = "GooglePlay"
    GOOGLE_TRANSLATE = "GoogleTranslate"
    GREEN_OPEN_AI = "GreenOpenAI"
    OPEN_AI = "OpenAI"
    GTA_FIVE = "GtaFive"
    NVIDIA = "NVIDIA"
    OUTLOOK_MAIL = "OutlookMail"
    STEAM = "Steam"
    TELEGRAM = "Telegram"
    VS_CODE = "VsCode"
    XIAO_MI = "XiaoMi"

    def path(self, theme=Theme.AUTO):
        return fr"..\..\data\images\icons\AppIcons\SVG\{self.value}.svg"

==> FluentWidgets-1.0.6-py3-none-any.whl: FluentWidgets/customwidgets/custom_fluent_icon.py <==
from enum import Enum

from qfluentwidgets import Theme, FluentIconBase, getIconColor


class WinPngFluentIcon(FluentIconBase, Enum):
    """ Custom Windows Style Icon (PNG) """

    ADD_CHAT = "AddChat"
    ADD_EMAIL = "AddEmail"
    ADD_FOLDER = "AddFolder"
    ADD_LINK = "AddLink"
    ADD_EMAIL_MESSAGE = "AddEmailMessage"
    ADDRESS = "Address"
    ATTACH = "Attach"
    CALC = "Calc"
    CALENDAR = "Calendar"
    CART = "Cart"
    CHAT = "Chat"
    CHAT_BUBBLES = "ChatBubbles"
    CHAT_MESSAGE = "ChatMessage"
    CLOUD = "Cloud"
    CLOUD_FOLDER = "CloudFolder"
    CODE_FOLDER = "CodeFolder"
    COLOR_WIFI = "ColorWifi"
    COMMENT = "Comment"
    CONTACT = "Contact"
    COPY_TO_FOLDER = "CopyToFolder"
    DATA_BASE = "DataBase"
    DEL_FOLDER = "DelFolder"
    DOCUMENT_FOLDER = "DocumentFolder"
    DOUBT = "Doubt"
    DOWN = "Down"
    DOWNLOAD_FOLDER = "DownloadFolder"
    DROP_DOWN = "DropDown"
    DROP_LEFT = "DropLeft"
    DROP_RIGHT = "DropRight"
    DROP_UP = "DropUp"
    EDIT_CALENDAR = "EditCalendar"
    EDIT_FILE = "EditFile"
    EMAIL_MESSAGE = "EmailMessage"
    ERROR_LINK = "ErrorLink"
    ERROR_WIFI = "ErrorWIFI"
    EXPLORER = "Explorer"
    FEMAIL_USER = "FemailUser"
    FINISH = "Finish"
    FOLDER = "Folder"
    FORWARD = "Forward"
    GAME_FOLDER = "GameFolder"
    GO_AHEAD = "GoAhead"
    HELP = "Help"
    INFO = "Info"
    LEFT = "Left"
    LIKE = "Like"
    LOW_POWER = "LowPower"
    MAN_USER = "ManUser"
    MESSAGE = "Message"
    MICROSOFT = "Microsoft"
    MORE = "More"
    MOVE_TO_FOLDER = "MoveToFolder"
    MSF_STORE = "MSFStore"
    MUSIC_FOLDER = "MusicFolder"
    NO_NETWORK = "NoNetwork"
    NOTEPAD = "Notepad"
    PAINT = "Paint"
    PICTURE_FOLDER = "PictureFolder"
    PLAY = "Play"
    QUICK_SHARK = "QuickShark"
    RADIUS_WIN11_LOG = "RadiusWin11Log"
    REGEDIT = "Regedit"
    RETURN = "Return"
    RIGHT = "Right"
    SEND = "Send"
    RIGHT_SIGN_IN = "RightSignIn"
    ROTATION_LEFT = "RotationLeft"
    ROTATION_RIGHT = "RotationRight"
    ROUND = "Round"
    SAN_WARNING = "SanWarning"
    SAVE = "Save"
    SEARCH_CHAT = "SearchChat"
    SEARCH_MORE = "SearchMore"
    SETTING = "Setting"
    SHARK = "Shark"
    SHI_ZHON = "ShiZhon"
    SIGN = "Sign"
    SORT_DOWN = "SortDown"
    SORT_LEFT = "SortLeft"
    SORT_RIGHT = "SortRight"
    SORT_UP = "SortUp"
    SUN_CLOUD = "SunCloud"
    TERMINAL = "Terminal"
    TOOL = "Tool"
    TOP_SEND = "TopSend"
    VIDEO = "Video"
    VIDEO_FOLDER = "VideoFolder"
    WARNING = "Warning"
    WEATHER = "Weather"
    WHITE_WIFI = "WhiteWIFI"
    ZIP_FOLDER = "ZipFolder"
    WIN_11_LOG = "Win11Log"
    XIAN_JI = "XianJi"
    XIN_HAO = "XinHao"
    ZERO = "Zero"
    ONE = "One"
    TWO = "Two"
    THREE = "Three"
    FOUR = "Four"
    FIVE = "Five"
    SIX = "Six"
    SEVEN = "Seven"
    EIGHT = "Eight"
    NINE = "Nine"
    TEN = "Ten"
    ROUND_ZERO = "RoundZero"
    ROUND_ONE = "RoundOne"
    ROUND_TWO = "RoundTwo"
    ROUND_THREE = "RoundThree"
    ROUND_FOUR = "RoundFour"
    ROUND_FIVE = "RoundFive"
    ROUND_SIX = "RoundSix"
    ROUND_SEVEN = "RoundSeven"
    ROUND_EIGHT = "RoundEight"
    ROUND_NINE = "RoundNine"

    def path(self, theme=Theme.AUTO):
        # return f"C:\Projects\Items\Python\QFluentWidgets\data\images\logo\{self.value}.png"
        return fr"..\data\images\icons\WindowStyleIcons\PNG\{self.value}.png"


class WinSvgFluentIcon(FluentIconBase, Enum):
    """ Custom Window Style Icon (SVG) """

    CLoud = "Cloud"
    FINISH = "Finish"
    HOME = "Home"
    INFO = "Info"
    MENU = "Menu"
    MUSIC = "Music"
    PICTURE = "Picture"
    POWER_SHELL = "PowerShell"
    RECYCLE_BIN = "RecycleBin"
    WIN_10_COLOR_LOG = "Win10ColorLog"
    WIN_11_COLOR_LOG = "Win11ColorLog"


    def path(self, theme=Theme.AUTO):
        # return f"C:\Projects\Items\Python\QFluentWidgets\data\images\logo\{self.value}.png"
        return fr"..\data\images\icons\WindowStyleIcons\SVG\{self.value}.svg"


class CustomFluentIcon(FluentIconBase, Enum):
    """ Custom Fluent Icon"""

    ADD_CHAT = "AddChat"
    ADD_FILE = "AddFile"
    ATTACH = "Attach"
    CHAT = "Chat"
    CHAT_BUBBLES = "ChatBubbles"
    CHAT_MESSAGE = "ChatMessage"
    EDIT_FILE = "EditFile"
    EMAIL_MESSAGE = "EmailMessage"
    FINISH = "Finish"
    NONE_BILI = "NoneBili"
    OPEN_FILE = "OpenFile"
    OPEN_FOLDER = "OpenFolder"
    SEND = "Send"
    SEND_FILL = "SendFill"

    def path(self, theme=Theme.AUTO):
        return fr"..\data\images\icons\NormalIcon\{self.value}\{getIconColor()}.png"


class ColorFluentIcon(FluentIconBase, Enum):
    """ Color Fluent Icon """

    ADD = "Add"
    ADOBE = "Adobe"
    PDF = "PDF"
    AE = "AE"
    AI = "AI"
    AN = "AN"
    AU = "AU"
    DW = "DW"
    ID = "ID"
    PR = "PR"
    PS = "PS"
    XD = "XD"
    FLY_MODE = "FlyModule"
    CHROME = "GoogleChrome"
    MAC = "MAC"
    APPLE_STORE = "AppStore"

    def path(self, theme=Theme.AUTO):
        return fr"..\data\images\icons\ColorStyleIcons\{self.value}.png"


class AppFluentIcon(FluentIconBase, Enum):

    AMD = "AMD"
    CALL_OF_DUTY = "CallOfDuty"
    CSGO = "CSGO"
    EDGE = "Edge"
    WORD = "Word"
    EXCEL = "Excel"
    PPT = "PPT"
    GMAIL = "Gmail"
    CHROME = "GoogleChrome"
    GOOGLE_CLOUD_DISK = "GoogleCloudDisk"
    GOOGLE_DOCUMENT = "GoogleDocument"
    GOOGLE_PLAY = "GooglePlay"
    GOOGLE_TRANSLATE = "GoogleTranslate"
    GREEN_OPEN_AI = "GreenOpenAI"
    OPEN_AI = "OpenAI"
    GTA_FIVE = "GtaFive"
    NVIDIA = "NVIDIA"
    OUTLOOK_MAIL = "OutlookMail"
    STEAM = "Steam"
    TELEGRAM = "Telegram"
    VS_CODE = "VsCode"
    XIAO_MI = "XiaoMi"

    def path(self, theme=Theme.AUTO):
        return fr"..\data\images\icons\AppIcons\SVG\{self.value}.svg"
